@@ -1,7 +1,7 @@
 use v6;
 use fatal;
 
-unit class Getopt::Long:ver<0.3.0>;
+unit class Getopt::Long:ver<0.3.1>;
 
 class Exception is CORE::Exception {
 	has Str:D $.message is required;
@@ -39,6 +39,9 @@ my sub convert(Code:D $converter, Str:D $value) {
 		when X::Numeric::CannotConvert {
 			die ValueInvalid.new("Cannot convert %s argument $_.source() to {$_.target // $_.target.perl}: $_.reason()");
 		}
+		when X::Temporal {
+			die ValueInvalid.new(.message.subst(/'string ' ( \' .* \' ) <.before ';'> /, { "$0 given as %s argument" }));
+		}
 		default {
 			die ValueInvalid.new("Can not convert %s argument \"$value\": {.message}");
 		}
@@ -150,6 +153,7 @@ my %converter-for-type{Any:U} = (
 	Pair.new(IO,       *.IO),
 	Pair.new(DateTime, *.DateTime),
 	Pair.new(Date,     *.Date),
+	Pair.new(Version,  *.Version),
 	Pair.new(Any,      &val),
 );
 
@@ -163,7 +167,8 @@ my sub type-for-format(Str:D $format) {
 		c => Complex,
 		p => IO::Path,
 		d => DateTime,
-		a => Date;
+		a => Date,
+		v => Version;
 	die ConverterInvalid.new("No such format $format for %s") if not %type-for-format{$format}:exists;
 	return %type-for-format{$format};
 };
@@ -660,6 +665,7 @@ It supports the following types for named and positional arguments:
 =item IO::Path
 =item DateTime
 =item Date
+=item Version
 
 It also supports any enum type, and any coercion type that uses any of
 the aforementioned types as its contraint type (e.g. C<Foo(Str)>).
